==> wow_views-0.0.6.tar.gz: lib/compoment/view/DanhSachNamDoc2.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/imageUrl.dart';
import 'package:wowit/methods.dart';

class DanhSachNamDoc2 {
  Widget getMainView(Map<String, dynamic> data) {
    var dsSuKien = Methods.getList(data['data'], 'sp_dsSuKien');
    var dsAction = Methods.getList(data, 'dsAction');
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    return ListView.builder(itemBuilder: (context, index) {
      return InkWell(
        onTap: (){
          print('onTap item ds nam doc 2 - ID:3');
          for(var item in dsAction){
            if(Methods.getInt(item, 'ID') == 3){
              iAction.goToViewById(
                  Methods.getInt(item, 'idView'),
                  Methods.getInt(dsSuKien[index], 'ID')
              );
              break;
            }
          }
        },
        onLongPress: (){
          print('onLongTap item ds nam doc 2');
          // DynamicView.actionCompomentView(3, dsAction,idData: Methods.getInt(dsSuKien[index], 'ID'));
        },
        child: Card(child: Column(children: [
          _hinhAnh(Methods.getString(dsSuKien[index], 'hinhAnh_image_path')),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text(Methods.getString(dsSuKien[index], 'title'),maxLines: 1,
              style: TextStyle(
                color: Colors.black,
                fontWeight: FontWeight.normal,
                fontSize: 16,
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(bottom: 8,right: 8,left: 8),
            child: _thoGian(Methods.showDate(Methods.getDateTime(dsSuKien[index], 'createDate'))),
          )
        ],
          crossAxisAlignment: CrossAxisAlignment.start,
        ),
        ),
      );
    },itemCount: dsSuKien.length,
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
    );
  }

  Widget _hinhAnh(String hinhAnh){
    return ClipRRect(
      borderRadius: const BorderRadius.only(
        topRight: Radius.circular(5),
        topLeft: Radius.circular(5),
      ),
      child: Image.network(
        Methods.getURL(hinhAnh),
        height: 200,
        width: Get.width,
        fit: BoxFit.fill,
      ),
    );
  }

  Widget _thoGian(String createDate){
    return Row(children: [
      Image.network(Methods.getURL(ImageByID.getUrlImage(2206), ),height: 20, width: 20,),
      const SizedBox(width: 8,),
      Text(createDate,
        style:const TextStyle(
          color: Color(0xff6B6B6B),
          fontWeight: FontWeight.normal,
          fontSize: 16,
        ),
      )
    ],);
  }
}

==> wow_views-0.0.7.tar.gz: lib/compoment/view/DanhSachNamDoc2.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/imageUrl.dart';
import 'package:wowit/methods.dart';

class DanhSachNamDoc2 {
  Widget getMainView(Map<String, dynamic> data,String tableName) {
    var dsSuKien = Methods.getList(data['data'], tableName);
    var dsAction = Methods.getList(data, 'dsAction');
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    return ListView.builder(itemBuilder: (context, index) {
      return InkWell(
        onTap: (){
          print('onTap item ds nam doc 2 - ID:3');
          for(var item in dsAction){
            if(Methods.getInt(item, 'idAction') == 3){
              iAction.goToViewById(
                  Methods.getInt(item, 'idView'),
                  Methods.getInt(dsSuKien[index], 'ID')
              );
              break;
            }
          }
        },
        onLongPress: (){
          print('onLongTap item ds nam doc 2');
          // DynamicView.actionCompomentView(3, dsAction,idData: Methods.getInt(dsSuKien[index], 'ID'));
        },
        child: Card(child: Column(children: [
          _hinhAnh(Methods.getString(dsSuKien[index], 'hinhAnh_image_path')),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text(Methods.getString(dsSuKien[index], 'title'),maxLines: 1,
              style: TextStyle(
                color: Colors.black,
                fontWeight: FontWeight.normal,
                fontSize: 16,
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(bottom: 8,right: 8,left: 8),
            child: _thoGian(Methods.showDate(Methods.getDateTime(dsSuKien[index], 'createDate'))),
          )
        ],
          crossAxisAlignment: CrossAxisAlignment.start,
        ),
        ),
      );
    },itemCount: dsSuKien.length,
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
    );
  }

  Widget _hinhAnh(String hinhAnh){
    return ClipRRect(
      borderRadius: const BorderRadius.only(
        topRight: Radius.circular(5),
        topLeft: Radius.circular(5),
      ),
      child: Image.network(
        Methods.getURL(hinhAnh),
        height: 200,
        width: Get.width,
        fit: BoxFit.fill,
      ),
    );
  }

  Widget _thoGian(String createDate){
    return Row(children: [
      Image.network(Methods.getURL(ImageByID.getUrlImage(2206), ),height: 20, width: 20,),
      const SizedBox(width: 8,),
      Text(createDate,
        style:const TextStyle(
          color: Color(0xff6B6B6B),
          fontWeight: FontWeight.normal,
          fontSize: 16,
        ),
      )
    ],);
  }
}
